#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_content.component.theme.interfaces import IThemesManagerTarget, IThemesManager, THEMES_MANAGER_KEY, \
    IThemesTarget, IThemesInfo, THEMES_INFO_KEY
from pyams_content.features.checker.interfaces import IContentChecker, ERROR_VALUE

# import packages
from persistent import Persistent
from pyams_content.features.checker import BaseContentChecker
from pyams_utils.adapter import adapter_config, get_annotation_adapter
from zope.container.contained import Contained
from zope.interface import implementer
from zope.schema.fieldproperty import FieldProperty

from pyams_content import _


@implementer(IThemesManager)
class ThemesManager(Persistent, Contained):
    """Themes manager persistent class"""

    thesaurus_name = FieldProperty(IThemesManager['thesaurus_name'])
    extract_name = FieldProperty(IThemesManager['extract_name'])


@adapter_config(context=IThemesManagerTarget, provides=IThemesManager)
def themes_manager_factory(target):
    """Themes manager factory"""
    return get_annotation_adapter(target, THEMES_MANAGER_KEY, ThemesManager, name='++themes-manager++')


@implementer(IThemesInfo)
class ThemesInfo(Persistent, Contained):
    """Themes info persistent class"""

    themes = FieldProperty(IThemesInfo['themes'])


@adapter_config(context=IThemesTarget, provides=IThemesInfo)
def themes_info_factory(target):
    """Themes info factory"""
    return get_annotation_adapter(target, THEMES_INFO_KEY, ThemesInfo, name='++themes++')


@adapter_config(name='themes', context=IThemesTarget, provides=IContentChecker)
class ThemesContentChecker(BaseContentChecker):
    """Themes info content checker"""

    label = _("Themes")
    weight = 200

    def inner_check(self, request):
        output = []
        translate = request.localizer.translate
        themes = IThemesInfo(self.context)
        if not themes.themes:
            output.append(translate(ERROR_VALUE).format(field=translate(IThemesInfo['themes'].title),
                                                        message=translate(_("no defined theme"))))
        return output
