#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_content.features.footer.interfaces import IFooterTarget, IFooterRenderer, IFooterSettings
from pyams_content.features.renderer.interfaces import HIDDEN_RENDERER_NAME
from pyams_skin.layer import IPyAMSLayer
from pyams_utils.interfaces.url import DISPLAY_CONTEXT

# import packages
from pyams_content.features.renderer.skin import BaseContentRenderer
from pyams_utils.adapter import adapter_config
from pyams_utils.traversing import get_parent
from pyramid.decorator import reify

from pyams_content import _


class BaseFooterRenderer(BaseContentRenderer):
    """Base footer renderer"""

    @reify
    def settings(self):
        if self.settings_interface is None:
            return None
        context = self.request.annotations.get(DISPLAY_CONTEXT)
        if context is None:
            context = self.context
        target = get_parent(context, IFooterTarget)
        settings = IFooterSettings(target)
        while settings.inherit:
            settings = IFooterSettings(settings.parent)
        return settings.settings


@adapter_config(name=HIDDEN_RENDERER_NAME, context=(IFooterTarget, IPyAMSLayer), provides=IFooterRenderer)
class HiddenFooterRenderer(BaseFooterRenderer):
    """Hidden footer renderer"""

    name = HIDDEN_RENDERER_NAME
    label = _("Hidden footer")
    weight = -999

    def render(self):
        return ''
